@@ -1,13 +1,13 @@
 use crate::common::{
     check_installed, create_named_virtualenv, create_virtualenv, maybe_mock_cargo, test_python_path,
 };
-use anyhow::{bail, Context, Result};
+use anyhow::{Context, Result, bail};
 #[cfg(feature = "zig")]
 use cargo_zigbuild::Zig;
 use clap::Parser;
-use fs4::fs_err3::FileExt;
 use fs_err::File;
-use maturin::{BuildOptions, PlatformTag, PythonInterpreter, Target};
+use fs4::fs_err3::FileExt;
+use maturin::{BuildOptions, PythonInterpreter, Target};
 use normpath::PathExt;
 use std::collections::HashSet;
 use std::env;
@@ -27,10 +27,12 @@ pub fn test_integration(
     maybe_mock_cargo();
 
     // Pass CARGO_BIN_EXE_maturin for testing purpose
-    env::set_var(
-        "CARGO_BIN_EXE_cargo-zigbuild",
-        env!("CARGO_BIN_EXE_maturin"),
-    );
+    unsafe {
+        env::set_var(
+            "CARGO_BIN_EXE_cargo-zigbuild",
+            env!("CARGO_BIN_EXE_maturin"),
+        )
+    };
 
     let package_string = package.as_ref().join("Cargo.toml").display().to_string();
 
@@ -64,13 +66,11 @@ pub fn test_integration(
     #[cfg(not(feature = "zig"))]
     let zig_found = false;
 
-    let test_zig = if zig && (env::var("GITHUB_ACTIONS").is_ok() || zig_found) {
+    if zig && (env::var("GITHUB_ACTIONS").is_ok() || zig_found) {
         cli.push("--zig".into());
-        true
     } else {
         cli.push("--compatibility".into());
         cli.push("linux".into());
-        false
     };
 
     // One scope up to extend the lifetime
@@ -159,20 +159,6 @@ pub fn test_integration(
     // order they are in the build context
     for ((filename, supported_version), python_interpreter) in wheels.iter().zip(interpreter) {
         check_for_duplicates(filename)?;
-        if test_zig
-            && build_context.target.is_linux()
-            && !build_context.target.is_musl_libc()
-            && build_context.target.get_minimum_manylinux_tag() != PlatformTag::Linux
-        {
-            let rustc_ver = rustc_version::version()?;
-            let python_arch = build_context.target.get_python_arch();
-            let file_suffix = if rustc_ver >= semver::Version::new(1, 64, 0) {
-                format!("manylinux_2_17_{python_arch}.manylinux2014_{python_arch}.whl")
-            } else {
-                format!("manylinux_2_12_{python_arch}.manylinux2010_{python_arch}.whl")
-            };
-            assert!(filename.to_string_lossy().ends_with(&file_suffix))
-        }
         let mut venv_name = if supported_version == "py3" {
             format!("{unique_name}-py3")
         } else {
